# sosw
Serverless Orchestrator of Serverless Workers for AWS - Worker
[![Build Status](https://travis-ci.org/bimpression/sosw.svg?branch=master)](https://travis-ci.org/bimpression/sosw)

Documentation can be found in [sosw.rtfd.io](https://sosw.rtfd.io/latest)
